==> apache-camel-3.22.4-src.zip: apache-camel-3.22.4/components/camel-jms/src/test/java/org/apache/camel/component/jms/JmsToTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jms;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

public class JmsToTest extends AbstractJMSTest {

    @Test
    public void testTo() throws Exception {
        getMockEndpoint("mock:JmsToTest.bar").expectedMessageCount(0);
        getMockEndpoint("mock:JmsToTest.beer").expectedMessageCount(0);
        getMockEndpoint("mock:where").expectedMessageCount(2);

        template.sendBodyAndHeader("direct:start", "Hello bar", "where", "JmsToTest.bar");
        template.sendBodyAndHeader("direct:start", "Hello beer", "where", "JmsToTest.beer");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected String getComponentName() {
        return "activemq";
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                // wrongly using to instead of toD
                from("direct:start").to("activemq:queue:${header.where}");

                from("activemq:queue:JmsToTest.bar").to("mock:JmsToTest.bar");
                from("activemq:queue:JmsToTest.beer").to("mock:JmsToTest.beer");

                // and all the messages goes here
                from("activemq:queue:${header.where}").to("mock:where");
            }
        };
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-jms/src/test/java/org/apache/camel/component/jms/JmsToTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jms;

import org.apache.camel.CamelContext;
import org.apache.camel.ConsumerTemplate;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.infra.core.CamelContextExtension;
import org.apache.camel.test.infra.core.DefaultCamelContextExtension;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.RegisterExtension;

public class JmsToTest extends AbstractJMSTest {

    @Order(2)
    @RegisterExtension
    public static CamelContextExtension camelContextExtension = new DefaultCamelContextExtension();
    protected CamelContext context;
    protected ProducerTemplate template;
    protected ConsumerTemplate consumer;

    @Test
    public void testTo() throws Exception {
        getMockEndpoint("mock:JmsToTest.bar").expectedMessageCount(0);
        getMockEndpoint("mock:JmsToTest.beer").expectedMessageCount(0);
        getMockEndpoint("mock:where").expectedMessageCount(2);

        template.sendBodyAndHeader("direct:start", "Hello bar", "where", "JmsToTest.bar");
        template.sendBodyAndHeader("direct:start", "Hello beer", "where", "JmsToTest.beer");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected String getComponentName() {
        return "activemq";
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                // wrongly using to instead of toD
                from("direct:start").to("activemq:queue:${header.where}");

                from("activemq:queue:JmsToTest.bar").to("mock:JmsToTest.bar");
                from("activemq:queue:JmsToTest.beer").to("mock:JmsToTest.beer");

                // and all the messages goes here
                from("activemq:queue:${header.where}").to("mock:where");
            }
        };
    }

    @Override
    public CamelContextExtension getCamelContextExtension() {
        return camelContextExtension;
    }

    @BeforeEach
    void setUpRequirements() {
        context = camelContextExtension.getContext();
        template = camelContextExtension.getProducerTemplate();
        consumer = camelContextExtension.getConsumerTemplate();
    }
}
